@@ -3,7 +3,7 @@ package Myriad;
 
 use Myriad::Class;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 =encoding utf8
@@ -91,11 +91,11 @@ Details on the request are in L<Myriad::RPC::Request> and the response to be sen
 
 =over 4
 
-=item * L<Myriad::RPC::Redis>
+=item * L<Myriad::RPC::Implementation::Redis>
 
-=item * L<Myriad::RPC::PostgreSQL>
+=item * L<Myriad::RPC::Implementation::PostgreSQL>
 
-=item * L<Myriad::RPC::Memory>
+=item * L<Myriad::RPC::Implementation::Memory>
 
 =back
 
@@ -109,11 +109,11 @@ Subscription implementations include:
 
 =over 4
 
-=item * L<Myriad::Subscription::Redis>
+=item * L<Myriad::Subscription::Implementation::Redis>
 
-=item * L<Myriad::Subscription::PostgreSQL>
+=item * L<Myriad::Subscription::Implementation::PostgreSQL>
 
-=item * L<Myriad::Subscription::Memory>
+=item * L<Myriad::Subscription::Implementation::Memory>
 
 =back
 
@@ -181,7 +181,6 @@ use Myriad::Transport::Redis;
 use Log::Any::Adapter;
 
 use Net::Async::OpenTracing;
-use Metrics::Any::Adapter qw(DogStatsd);
 
 our $REGISTRY;
 BEGIN {
@@ -298,6 +297,7 @@ async method configure_from_argv (@args) {
 
     $self->setup_logging;
     $self->setup_tracing;
+    $self->setup_metrics;
 
     $commands = Myriad::Commands->new(
         myriad => $self
@@ -670,6 +670,42 @@ method setup_tracing () {
     return;
 }
 
+=head2 setup_metrics
+
+Prepare L<Metrics::Any::Adapter> to collect metrics.
+
+=cut
+
+method setup_metrics () {
+    my $adapter = $config->metrics_adapter;
+    my $host = $config->metrics_host;
+    my $port = $config->metrics_port;
+
+    # Metrics::Any::Adapter use a lexical variable to identify
+    # the adapter instance that doesn't allow easy overrides.
+    my $metrics_adapter;
+    {
+        no warnings 'redefine';
+        *Metrics::Any::Adapter::adapter = sub {
+            return $metrics_adapter //= Metrics::Any::Adapter->class_for_type(
+                $adapter->as_string,
+            )->new(
+                host => $host->as_string,
+                port => $port->as_numeric,
+        )   ;
+        };
+    }
+    my $code = sub {
+        undef $metrics_adapter;
+    };
+
+    $adapter->subscribe($code);
+    $host->subscribe($code);
+    $port->subscribe($code);
+
+    return;
+}
+
 =head2 run
 
 Starts the main loop.
@@ -853,4 +889,3 @@ Deriv Group Services Ltd. C<< DERIV@cpan.org >>
 =head1 LICENSE
 
 Copyright Deriv Group Services Ltd 2020-2021. Licensed under the same terms as Perl itself.
-
