@@ -3,7 +3,7 @@ package Myriad::Class;
 use strict;
 use warnings;
 
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 use utf8;
@@ -233,21 +233,6 @@ sub import {
     List::Keywords->import(qw(any all));
     Syntax::Keyword::Match->import(qw(match));
 
-    # For history here, see this:
-    # https://rt.cpan.org/Ticket/Display.html?id=132337
-    # At the time of writing, ->begin_class is undocumented
-    # but can be seen in action in this test:
-    # https://metacpan.org/source/PEVANS/Object-Pad-0.21/t/70mop-create-class.t#L30
-    Object::Pad->import_into($pkg);
-    my $meta = Object::Pad->begin_class(
-        $pkg,
-        (
-            $args{extends}
-            ? (extends => $args{extends})
-            : ()
-        )
-    );
-
     {
         no strict 'refs';
         # Essentially the same as importing Log::Any qw($log) for now,
@@ -259,7 +244,26 @@ sub import {
         );
         *{$pkg . '::tracer'}  = \(OpenTracing->global_tracer);
     }
-    return $meta;
+
+    if(my $class = $args{class} || $pkg) {
+        # For history here, see this:
+        # https://rt.cpan.org/Ticket/Display.html?id=132337
+        # At the time of writing, ->begin_class is undocumented
+        # but can be seen in action in this test:
+        # https://metacpan.org/source/PEVANS/Object-Pad-0.21/t/70mop-create-class.t#L30
+        Object::Pad->import_into($pkg);
+        my $meta = Object::Pad::MOP::Class->begin_class(
+            $pkg,
+            (
+                $args{extends}
+                ? (extends => $args{extends})
+                : ()
+            ),
+        );
+        # Note that `does` is not supported yet due to https://rt.cpan.org/Ticket/Display.html?id=137952
+        return $meta;
+    }
+    return $pkg;
 }
 
 1;
