@@ -2,14 +2,14 @@ package Myriad::Commands;
 
 use Myriad::Class;
 
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 =encoding utf8
 
 =head1 NAME
 
-Myriad::Commands
+Myriad::Commands - common abstraction for user interface commands
 
 =head1 DESCRIPTION
 
