@@ -2,7 +2,7 @@ package Myriad::Transport::Redis;
 
 use Myriad::Class extends => qw(IO::Async::Notifier);
 
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 =pod
@@ -613,6 +613,10 @@ async method getset($key, $v) {
     await $redis->set($self->apply_prefix($key), $v);
 }
 
+async method incr ($key) {
+    await $redis->incr($self->apply_prefix($key));
+}
+
 async method rpush($key, @v) {
     await $redis->rpush($self->apply_prefix($key), @v);
 }
